@@ -8,7 +8,7 @@ import queue
 #sys.path.append('/home/pi/gxf/python/spotii')
 #sys.path.append('/home/pi/gxf/python/spotii/test_chip_handler')
 
-from spotii.define import *
+from define import *
 
 #baseUrl = "https://www.locationnow.com/lnservices/ws"
 
@@ -41,7 +41,8 @@ class SendResult(threading.Thread):
           'Authorization': 'Basic bGFpcGFjOmxhaXBhY3dz',
           'Content-Type': 'application/json'
         }
-        
+#        print('save result:', payload)
+        print('save result:', payload)
         response = requests.request("POST", url, headers=headers, data=payload)
         
         print(response.text)
