@@ -12,27 +12,10 @@ parentdir = os.path.dirname(currentdir)
 sys.path.insert(0, parentdir)
 
 from test_handler.i2c_lib import i2c_device
-from test_handler.cassette_polling import CassettePolling
+#from test_handler.cassette_polling import CassettePolling
 from define import *
 import main_paras
 from on_off.mainboard_pio import hub_reset
-# from smbus import SMBus
-# import sys
-# sys.path.append('/home/pi/gxf/python/spotii')
-# sys.path.append('/home/pi/gxf/python/spotii/test_chip_handler')
-# import subprocess
-# import queue
-# 
-# from mythread import MyThread
-# import time
-# import threading
-# from i2c_lib import i2c_device
-# from takePhoto import takePhoto
-# from datetime import datetime,timezone
-# from define import *
-
- 
-
 I2C                 =0
 CAMERA              =1
 # part of "v4l2-ctl --list-devices" parsing sample sentence
@@ -77,6 +60,10 @@ def i2cMap(cMap):
             each[I2C] = INVALID_DEVICE_INDEX
         index+=1
 
+cmrMap=[]
+deviceReady = False
+def getDevice(index):
+    return deviceReady, cmrMap[index]
 
 
 class TestChipHandlerThread (threading.Thread):
@@ -87,9 +74,8 @@ class TestChipHandlerThread (threading.Thread):
         self.qCom = qForCom
         self.qGui = qForGui
         self.qForResult=qForResult
-        self.cassettePolling=[None]*5
-        self.i2c=[]
-        self.cmrMap=[]
+#        self.cassettePolling=[None]*5
+#        self.i2c=[]
         self.initDone = True
 
         self.deviceQue=[]
@@ -107,7 +93,7 @@ class TestChipHandlerThread (threading.Thread):
 # RESULT_TEXT        3
     def checkingStop(self, slotNumber):
         self.startCheck[slotNumber]=False
-        self.deviceQue[slotNumber].put(PHOTO_TAKING_STOP)
+        #self.deviceQue[slotNumber].put(PHOTO_TAKING_STOP)
         
     def checkingStart(self, slotNumber):
         self.startCheck[slotNumber] = True
@@ -124,78 +110,59 @@ class TestChipHandlerThread (threading.Thread):
         if result[RESULT_ERROR_CODE] == DEVICE_STATE_TAKING_PHOTO:
             self.checkingStart(result[RESULT_SLOT_NUMBER])
             self.qGui.put(result)
-        elif result[RESULT_ERROR_CODE] == DEVICE_STATE_MANUAL_FLIP:
-            #print('manual flip')
-            self.qGui.put(result)
-        elif result[RESULT_ERROR_CODE] == DEVICE_STATE_MANUAL_INVALID_QR:
-            self.qGui.put(result)
         elif result[RESULT_CASSETTE_ID] == '':
             self.qGui.put(result)
         elif self.startCheck[result[RESULT_SLOT_NUMBER]] == True:
+            self.resultReport(result)
+            self.checkingStop(result[RESULT_SLOT_NUMBER])
+            return;
             
-            if main_paras.info.getTestMode()==TEST_MODE_SPEED:
-                self.resultReport(result)
-                self.checkingStop(result[RESULT_SLOT_NUMBER])
-                return;
-            
-            if Negative_test_result == result[RESULT_ERROR_CODE] or Control_area_not_found == result[RESULT_ERROR_CODE] :                                
-                self.checkingResult[result[RESULT_SLOT_NUMBER]].append(result)
-                if len(self.checkingResult[result[RESULT_SLOT_NUMBER]]) == len(PHOTO_TAKING_GAPS)+1:
-                    self.resultReport(result)
-                    self.checkingStop(result[RESULT_SLOT_NUMBER])
-            elif Positive_test_result == result[RESULT_ERROR_CODE]: 
-                for each in self.checkingResult[result[RESULT_SLOT_NUMBER]]:
-                    if Positive_test_result == each[RESULT_ERROR_CODE]: ## report if get 2 poisitve result
-                        self.resultReport(result)
-                        self.checkingStop(result[RESULT_SLOT_NUMBER])
-                        break;                   
-                self.checkingResult[result[RESULT_SLOT_NUMBER]].append(result)
-            else:
-                self.checkingStop(result[RESULT_SLOT_NUMBER])
-                self.resultReport(result)
                 
     def run (self):
         super().run()
         print('test monitor run...')
+        global cmrMap
         
         for addr in I2C_DEVICE:
-            self.cmrMap.append([addr, INVALID_DEVICE_INDEX])            
+            cmrMap.append([addr, INVALID_DEVICE_INDEX])            
         for i in range(3):
-            if cameraMap(self.cmrMap)==True:
-                break;
-            self.qGui.put([NON_SLOT_INDEX, -1 , 'Critical error', 'Critical error'])
             hub_reset.off()
             time.sleep(0.5)
             hub_reset.on()
             time.sleep(4)           
+            if cameraMap(cmrMap)==True:
+                break;
+            self.qGui.put([NON_SLOT_INDEX, -1 , 'Critical error', 'Critical error'])
         else:
             self.initDone =False
              
-        print(self.cmrMap)
-        i2cMap(self.cmrMap)
-        print(self.cmrMap)
+        print(cmrMap)
+        i2cMap(cmrMap)
+        print(cmrMap)
         
         if self.initDone == False:
             self.qGui.put([NON_SLOT_INDEX, -1 , 'Critical error', 'Critical error'])
             while True:
                 None
 
-        for i in range(5):
-            self.cassettePolling[i]=CassettePolling(i, self.cmrMap[i][I2C], self.cmrMap[i][CAMERA], self.qForResult, self.qCom, self.deviceQue[i])
-            self.cassettePolling[i].start()
+#         for i in range(5):
+#             self.cassettePolling[i]=CassettePolling(i, self.cmrMap[i][I2C], self.cmrMap[i][CAMERA], self.qForResult, self.qCom, self.deviceQue[i])
+#             self.cassettePolling[i].start()
+        global deviceReady
+        deviceReady = True
         while True:
             result=self.qForResult.get() #[0, 1, 'La0012684', 'Negative']
             
             if result == CLOSE_NOW:
-                for i in range(5):
-                    self.cassettePolling[i].notify(CLOSE_NOW)
-                #for i in range(5):
-                self.cassettePolling[0].join()
-#                 self.cassettePolling[1].join()
-#                 self.cassettePolling[2].join()
-#                 self.cassettePolling[3].join()
-#                 self.cassettePolling[4].join()
-                print('got CLOSE_NOW')
+#                 for i in range(5):
+#                     self.cassettePolling[i].notify(CLOSE_NOW)
+#                 #for i in range(5):
+#                 self.cassettePolling[0].join()
+# #                 self.cassettePolling[1].join()
+# #                 self.cassettePolling[2].join()
+# #                 self.cassettePolling[3].join()
+# #                 self.cassettePolling[4].join()
+#                 print('got CLOSE_NOW')
                 break;
             else:
                 self.putToResultList(result)
@@ -241,9 +208,9 @@ def i2cTest():
     
 def cameraMapTest():
     hub_reset.off()
-    time.sleep(0.1)
+    time.sleep(0.5)
     hub_reset.on()
-    time.sleep(2)
+    time.sleep(4)
     cmrMap=[]
     for addr in I2C_DEVICE:
         cmrMap.append([addr, INVALID_DEVICE_INDEX])
